use crate::responses::api_response::ApiResponse;
use crate::responses::steam_id_response::SteamIdResponse;
use serde::Deserialize;
use serde::Serialize;
use std::fs::File;
use std::io::Read;

#[derive(Serialize, Deserialize)]
pub struct User {
    pub username: String,
}

#[derive(Serialize, Deserialize)]
pub struct Config {
    pub steam_api_key: String,
    pub user: User,
}

impl Config {
    pub fn new() -> Config {
        let mut config_file = File::open("config.toml").expect("Failed to open config.toml");
        let mut contents = String::new();
        config_file
            .read_to_string(&mut contents)
            .expect("Failed to read config.toml");
        let config: Config = toml::from_str(&contents).expect("Failed to parse config.toml");

        Config {
            steam_api_key: config.steam_api_key,
            user: config.user,
        }
    }

    pub fn get_steam_id(&self, username: Option<&String>) -> String {
        let username = username.unwrap_or(&self.user.username);
        match reqwest::blocking::get(format!(
            "https://api.steampowered.com/ISteamUser/ResolveVanityURL/v0001/?key={}&vanityurl={}",
            self.steam_api_key, username
        )) {
            Ok(res) => match res.text() {
                Ok(text) => {
                    let api_response: ApiResponse<SteamIdResponse> =
                        serde_json::from_str(&text).unwrap();
                    api_response.response.steamid
                }
                Err(_) => panic!("Error getting steamid."),
            },
            Err(_) => panic!("Error getting steamid."),
        }
    }
}
