use crate::config::Config;
use crate::game::Game;
use crate::responses::api_response::ApiResponse;
use rand::seq::IteratorRandom;
use serde::{Deserialize, Serialize};

#[derive(Serialize, Deserialize)]
pub struct GameList {
    pub game_count: i32,
    pub games: Vec<Game>,
}

impl GameList {
    pub fn new() -> GameList {
        GameList {
            game_count: 0,
            games: Vec::new(),
        }
    }

    pub fn update(&mut self) {
        let config = Config::new();
        match reqwest::blocking::get(format!("https://api.steampowered.com/IPlayerService/GetOwnedGames/v0001/?key={}&steamid={}&format=json&include_appinfo=true",
                                             config.steam_api_key,
                                             config.get_steam_id(Some(&config.user.username))
        )) {
            Ok(res) => {
                match res.text() {
                    Ok(text) => {
                        let api_response: ApiResponse<GameList>= serde_json::from_str(&text).unwrap();
                        self.games = api_response.response.games;
                    },
                    Err(_) => println!("Error getting list") ,
                }
            }
            Err(_) => println!("Error getting list") ,
        }
    }

    pub fn pick(&self) -> Option<Game> {
        self.games.iter().choose(&mut rand::rng()).cloned()
    }

    pub fn pick_unplayed(&self) -> Option<Game> {
        self.games
            .iter()
            .filter(|&game| game.playtime_forever == Some(0))
            .choose(&mut rand::rng())
            .cloned()
    }
}
